/**************************************************************************************************
   LED_Main.c - 8-Digit LED Display

   Date: March 2015

   Configuration:
       MCU:                STM32F415RG
       Development Board:  Mini-M4 for STM32
       Crystal Oscillator: 16 MHz
       System Clock:       120 MHz
       Compiler:           mikroC PRO for ARM version 4.5.2
       Program Loader:     USB_HID Bootloader
       Power:              USB cable

   External Circuit:
       MAX6951 LED Display Driver chip.

**************************************************************************************************/

// Include Files
#include "USB_Driver.h"
#include "Timers.h"
#include "LED_Driver.h"
#include "LED.h"

// Variables
unsigned short int MainTimer;          // Timer handle for this module







void main() {

     USB_Init();                       // Initialize USB

     Timer_Init();                     // Initialize timers
     LED_Initialize();

     MainTimer = get_timer();          // Get a timer handle
     set_timer(MainTimer,2000);        // Set timer

     // Delay while USB enumerates
     while (check_timer(MainTimer) != 0) {
     }
     USB_PutQueue(" ");
     USB_PutQueue("LED display program started");



     Display_Init();



     EnableInterrupts();               // Global enable interrupts

     // Main loop
     while (1) {

         USB_CheckIn();                // Check for incoming USB messages
         USB_CheckOut();               // Check for outgoing USB messages

         TimerCheck();                 // Check timer pool
     }
}




/**************************************************************************************************
  EOF
**************************************************************************************************/